class Process(Component,IComponent,IDisposable):
 """
 Provides access to local and remote processes and enables you to start and stop local system processes.

 

 Process()
 """
 def BeginErrorReadLine(self):
  """
  BeginErrorReadLine(self: Process)

   Begins asynchronous read operations on the redirected System.Diagnostics.Process.StandardError 

    stream of the application.
  """
  pass
 def BeginOutputReadLine(self):
  """
  BeginOutputReadLine(self: Process)

   Begins asynchronous read operations on the redirected System.Diagnostics.Process.StandardOutput 

    stream of the application.
  """
  pass
 def CancelErrorRead(self):
  """
  CancelErrorRead(self: Process)

   Cancels the asynchronous read operation on the redirected 

    System.Diagnostics.Process.StandardError stream of an application.
  """
  pass
 def CancelOutputRead(self):
  """
  CancelOutputRead(self: Process)

   Cancels the asynchronous read operation on the redirected 

    System.Diagnostics.Process.StandardOutput stream of an application.
  """
  pass
 def Close(self):
  """
  Close(self: Process)

   Frees all the resources that are associated with this component.
  """
  pass
 def CloseMainWindow(self):
  """
  CloseMainWindow(self: Process) -> bool

  

   Closes a process that has a user interface by sending a close message to its main window.

   Returns: true if the close message was successfully sent; false if the associated process does not have a 

    main window or if the main window is disabled (for example if a modal dialog is being shown).
  """
  pass
 def Dispose(self):
  """
  Dispose(self: Process,disposing: bool)

   Release all resources used by this process.

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 @staticmethod
 def EnterDebugMode():
  """
  EnterDebugMode()

   Puts a System.Diagnostics.Process component in state to interact with operating system processes 

    that run in a special mode by enabling the native property SeDebugPrivilege on the current 

    thread.
  """
  pass
 @staticmethod
 def GetCurrentProcess():
  """
  GetCurrentProcess() -> Process

  

   Gets a new System.Diagnostics.Process component and associates it with the currently active 

    process.

  

   Returns: A new System.Diagnostics.Process component associated with the process resource that is running 

    the calling application.
  """
  pass
 @staticmethod
 def GetProcessById(processId,machineName=None):
  """
  GetProcessById(processId: int) -> Process

  

   Returns a new System.Diagnostics.Process component,given the identifier of a process on the 

    local computer.

  

  

   processId: The system-unique identifier of a process resource.

   Returns: A System.Diagnostics.Process component that is associated with the local process resource 

    identified by the processId parameter.

  

  GetProcessById(processId: int,machineName: str) -> Process

  

   Returns a new System.Diagnostics.Process component,given a process identifier and the name of a 

    computer on the network.

  

  

   processId: The system-unique identifier of a process resource.

   machineName: The name of a computer on the network.

   Returns: A System.Diagnostics.Process component that is associated with a remote process resource 

    identified by the processId parameter.
  """
  pass
 @staticmethod
 def GetProcesses(machineName=None):
  """
  GetProcesses(machineName: str) -> Array[Process]

  

   Creates a new System.Diagnostics.Process component for each process resource on the specified 

    computer.

  

  

   machineName: The computer from which to read the list of processes.

   Returns: An array of type System.Diagnostics.Process that represents all the process resources running on 

    the specified computer.

  

  GetProcesses() -> Array[Process]

  

   Creates a new System.Diagnostics.Process component for each process resource on the local 

    computer.

  

   Returns: An array of type System.Diagnostics.Process that represents all the process resources running on 

    the local computer.
  """
  pass
 @staticmethod
 def GetProcessesByName(processName,machineName=None):
  """
  GetProcessesByName(processName: str,machineName: str) -> Array[Process]

  

   Creates an array of new System.Diagnostics.Process components and associates them with all the 

    process resources on a remote computer that share the specified process name.

  

  

   processName: The friendly name of the process.

   machineName: The name of a computer on the network.

   Returns: An array of type System.Diagnostics.Process that represents the process resources running the 

    specified application or file.

  

  GetProcessesByName(processName: str) -> Array[Process]

  

   Creates an array of new System.Diagnostics.Process components and associates them with all the 

    process resources on the local computer that share the specified process name.

  

  

   processName: The friendly name of the process.

   Returns: An array of type System.Diagnostics.Process that represents the process resources running the 

    specified application or file.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def Kill(self):
  """
  Kill(self: Process)

   Immediately stops the associated process.
  """
  pass
 @staticmethod
 def LeaveDebugMode():
  """
  LeaveDebugMode()

   Takes a System.Diagnostics.Process component out of the state that lets it interact with 

    operating system processes that run in a special mode.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnExited(self,*args):
  """
  OnExited(self: Process)

   Raises the System.Diagnostics.Process.Exited event.
  """
  pass
 def Refresh(self):
  """
  Refresh(self: Process)

   Discards any information about the associated process that has been cached inside the process 

    component.
  """
  pass
 def Start(self,*__args):
  """
  Start(fileName: str) -> Process

  

   Starts a process resource by specifying the name of a document or application file and 

    associates the resource with a new System.Diagnostics.Process component.

  

  

   fileName: The name of a document or application file to run in the process.

   Returns: A new System.Diagnostics.Process component that is associated with the process resource,or 

    null,if no process resource is started (for example,if an existing process is reused).

  

  Start(fileName: str,arguments: str) -> Process

  

   Starts a process resource by specifying the name of an application and a set of command-line 

    arguments,and associates the resource with a new System.Diagnostics.Process component.

  

  

   fileName: The name of an application file to run in the process.

   arguments: Command-line arguments to pass when starting the process.

   Returns: A new System.Diagnostics.Process component that is associated with the process,or null,if no 

    process resource is started (for example,if an existing process is reused).

  

  Start(startInfo: ProcessStartInfo) -> Process

  

   Starts the process resource that is specified by the parameter containing process start 

    information (for example,the file name of the process to start) and associates the resource 

    with a new System.Diagnostics.Process component.

  

  

   startInfo: The System.Diagnostics.ProcessStartInfo that contains the information that is used to start the 

    process,including the file name and any command-line arguments.

  

   Returns: A new System.Diagnostics.Process component that is associated with the process resource,or null 

    if no process resource is started (for example,if an existing process is reused).

  

  Start(self: Process) -> bool

  

   Starts (or reuses) the process resource that is specified by the 

    System.Diagnostics.Process.StartInfo property of this System.Diagnostics.Process component and 

    associates it with the component.

  

   Returns: true if a process resource is started; false if no new process resource is started (for example,

    if an existing process is reused).

  

  Start(fileName: str,userName: str,password: SecureString,domain: str) -> Process

  

   Starts a process resource by specifying the name of an application,a user name,a password,and 

    a domain and associates the resource with a new System.Diagnostics.Process component.

  

  

   fileName: The name of an application file to run in the process.

   userName: The user name to use when starting the process.

   password: A System.Security.SecureString that contains the password to use when starting the process.

   domain: The domain to use when starting the process.

   Returns: A new System.Diagnostics.Process component that is associated with the process resource,or null 

    if no process resource is started (for example,if an existing process is reused).

  

  Start(fileName: str,arguments: str,userName: str,password: SecureString,domain: str) -> Process

  

   Starts a process resource by specifying the name of an application,a set of command-line 

    arguments,a user name,a password,and a domain and associates the resource with a new 

    System.Diagnostics.Process component.

  

  

   fileName: The name of an application file to run in the process.

   arguments: Command-line arguments to pass when starting the process.

   userName: The user name to use when starting the process.

   password: A System.Security.SecureString that contains the password to use when starting the process.

   domain: The domain to use when starting the process.

   Returns: A new System.Diagnostics.Process component that is associated with the process resource,or null 

    if no process resource is started (for example,if an existing process is reused).
  """
  pass
 def ToString(self):
  """
  ToString(self: Process) -> str

  

   Formats the process's name as a string,combined with the parent component type,if applicable.

   Returns: The System.Diagnostics.Process.ProcessName,combined with the base component's 

    System.Object.ToString return value.
  """
  pass
 def WaitForExit(self,milliseconds=None):
  """
  WaitForExit(self: Process)

   Instructs the System.Diagnostics.Process component to wait indefinitely for the associated 

    process to exit.

  

  WaitForExit(self: Process,milliseconds: int) -> bool

  

   Instructs the System.Diagnostics.Process component to wait the specified number of milliseconds 

    for the associated process to exit.

  

  

   milliseconds: The amount of time,in milliseconds,to wait for the associated process to exit. The maximum is 

    the largest possible value of a 32-bit integer,which represents infinity to the operating 

    system.

  

   Returns: true if the associated process has exited; otherwise,false.
  """
  pass
 def WaitForInputIdle(self,milliseconds=None):
  """
  WaitForInputIdle(self: Process) -> bool

  

   Causes the System.Diagnostics.Process component to wait indefinitely for the associated process 

    to enter an idle state. This overload applies only to processes with a user interface and,

    therefore,a message loop.

  

   Returns: true if the associated process has reached an idle state.

  WaitForInputIdle(self: Process,milliseconds: int) -> bool

  

   Causes the System.Diagnostics.Process component to wait the specified number of milliseconds for 

    the associated process to enter an idle state. This overload applies only to processes with a 

    user interface and,therefore,a message loop.

  

  

   milliseconds: A value of 1 to System.Int32.MaxValue that specifies the amount of time,in milliseconds,to 

    wait for the associated process to become idle. A value of 0 specifies an immediate return,and 

    a value of -1 specifies an infinite wait.

  

   Returns: true if the associated process has reached an idle state; otherwise,false.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 BasePriority=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the base priority of the associated process.



Get: BasePriority(self: Process) -> int



"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 EnableRaisingEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the System.Diagnostics.Process.Exited event should be raised when the process terminates.



Get: EnableRaisingEvents(self: Process) -> bool



Set: EnableRaisingEvents(self: Process)=value

"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 ExitCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value that the associated process specified when it terminated.



Get: ExitCode(self: Process) -> int



"""

 ExitTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the time that the associated process exited.



Get: ExitTime(self: Process) -> DateTime



"""

 Handle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the native handle of the associated process.



Get: Handle(self: Process) -> IntPtr



"""

 HandleCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of handles opened by the process.



Get: HandleCount(self: Process) -> int



"""

 HasExited=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the associated process has been terminated.



Get: HasExited(self: Process) -> bool



"""

 Id=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the unique identifier for the associated process.



Get: Id(self: Process) -> int



"""

 MachineName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the computer the associated process is running on.



Get: MachineName(self: Process) -> str



"""

 MainModule=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the main module for the associated process.



Get: MainModule(self: Process) -> ProcessModule



"""

 MainWindowHandle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the window handle of the main window of the associated process.



Get: MainWindowHandle(self: Process) -> IntPtr



"""

 MainWindowTitle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the caption of the main window of the process.



Get: MainWindowTitle(self: Process) -> str



"""

 MaxWorkingSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum allowable working set size for the associated process.



Get: MaxWorkingSet(self: Process) -> IntPtr



Set: MaxWorkingSet(self: Process)=value

"""

 MinWorkingSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the minimum allowable working set size for the associated process.



Get: MinWorkingSet(self: Process) -> IntPtr



Set: MinWorkingSet(self: Process)=value

"""

 Modules=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the modules that have been loaded by the associated process.



Get: Modules(self: Process) -> ProcessModuleCollection



"""

 NonpagedSystemMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the nonpaged system memory size allocated to this process.



Get: NonpagedSystemMemorySize(self: Process) -> int



"""

 NonpagedSystemMemorySize64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the amount of nonpaged system memory allocated for the associated process.



Get: NonpagedSystemMemorySize64(self: Process) -> Int64



"""

 PagedMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the paged memory size.



Get: PagedMemorySize(self: Process) -> int



"""

 PagedMemorySize64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the amount of paged memory allocated for the associated process.



Get: PagedMemorySize64(self: Process) -> Int64



"""

 PagedSystemMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the paged system memory size.



Get: PagedSystemMemorySize(self: Process) -> int



"""

 PagedSystemMemorySize64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the amount of pageable system memory allocated for the associated process.



Get: PagedSystemMemorySize64(self: Process) -> Int64



"""

 PeakPagedMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the peak paged memory size.



Get: PeakPagedMemorySize(self: Process) -> int



"""

 PeakPagedMemorySize64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the maximum amount of memory in the virtual memory paging file used by the associated process.



Get: PeakPagedMemorySize64(self: Process) -> Int64



"""

 PeakVirtualMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the peak virtual memory size.



Get: PeakVirtualMemorySize(self: Process) -> int



"""

 PeakVirtualMemorySize64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the maximum amount of virtual memory used by the associated process.



Get: PeakVirtualMemorySize64(self: Process) -> Int64



"""

 PeakWorkingSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the peak working set size for the associated process.



Get: PeakWorkingSet(self: Process) -> int



"""

 PeakWorkingSet64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the maximum amount of physical memory used by the associated process.



Get: PeakWorkingSet64(self: Process) -> Int64



"""

 PriorityBoostEnabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the associated process priority should temporarily be boosted by the operating system when the main window has the focus.



Get: PriorityBoostEnabled(self: Process) -> bool



Set: PriorityBoostEnabled(self: Process)=value

"""

 PriorityClass=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the overall priority category for the associated process.



Get: PriorityClass(self: Process) -> ProcessPriorityClass



Set: PriorityClass(self: Process)=value

"""

 PrivateMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the private memory size.



Get: PrivateMemorySize(self: Process) -> int



"""

 PrivateMemorySize64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the amount of private memory allocated for the associated process.



Get: PrivateMemorySize64(self: Process) -> Int64



"""

 PrivilegedProcessorTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the privileged processor time for this process.



Get: PrivilegedProcessorTime(self: Process) -> TimeSpan



"""

 ProcessName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the process.



Get: ProcessName(self: Process) -> str



"""

 ProcessorAffinity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the processors on which the threads in this process can be scheduled to run.



Get: ProcessorAffinity(self: Process) -> IntPtr



Set: ProcessorAffinity(self: Process)=value

"""

 Responding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the user interface of the process is responding.



Get: Responding(self: Process) -> bool



"""

 SafeHandle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SafeHandle(self: Process) -> SafeProcessHandle



"""

 SessionId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Terminal Services session identifier for the associated process.



Get: SessionId(self: Process) -> int



"""

 StandardError=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a stream used to read the error output of the application.



Get: StandardError(self: Process) -> StreamReader



"""

 StandardInput=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a stream used to write the input of the application.



Get: StandardInput(self: Process) -> StreamWriter



"""

 StandardOutput=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a stream used to read the output of the application.



Get: StandardOutput(self: Process) -> StreamReader



"""

 StartInfo=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the properties to pass to the System.Diagnostics.Process.Start method of the System.Diagnostics.Process.



Get: StartInfo(self: Process) -> ProcessStartInfo



Set: StartInfo(self: Process)=value

"""

 StartTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the time that the associated process was started.



Get: StartTime(self: Process) -> DateTime



"""

 SynchronizingObject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object used to marshal the event handler calls that are issued as a result of a process exit event.



Get: SynchronizingObject(self: Process) -> ISynchronizeInvoke



Set: SynchronizingObject(self: Process)=value

"""

 Threads=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the set of threads that are running in the associated process.



Get: Threads(self: Process) -> ProcessThreadCollection



"""

 TotalProcessorTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total processor time for this process.



Get: TotalProcessorTime(self: Process) -> TimeSpan



"""

 UserProcessorTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the user processor time for this process.



Get: UserProcessorTime(self: Process) -> TimeSpan



"""

 VirtualMemorySize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size of the process's virtual memory.



Get: VirtualMemorySize(self: Process) -> int



"""

 VirtualMemorySize64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the amount of the virtual memory allocated for the associated process.



Get: VirtualMemorySize64(self: Process) -> Int64



"""

 WorkingSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the associated process's physical memory usage.



Get: WorkingSet(self: Process) -> int



"""

 WorkingSet64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the amount of physical memory allocated for the associated process.



Get: WorkingSet64(self: Process) -> Int64



"""


 ErrorDataReceived=None
 Exited=None
 OutputDataReceived=None




class Random(object):
 """
 Represents a pseudo-random number generator,a device that produces a sequence of numbers that meet certain statistical requirements for randomness.

 

 Random()

 Random(Seed: int)
 """
 def Next(self,*__args):
  """
  Next(self: Random,maxValue: int) -> int

  

   Returns a nonnegative random number less than the specified maximum.

  

   maxValue: The exclusive upper bound of the random number to be generated. maxValue must be greater than or 

    equal to zero.

  

   Returns: A 32-bit signed integer greater than or equal to zero,and less than maxValue; that is,the 

    range of return values ordinarily includes zero but not maxValue. However,if maxValue equals 

    zero,maxValue is returned.

  

  Next(self: Random,minValue: int,maxValue: int) -> int

  

   Returns a random number within a specified range.

  

   minValue: The inclusive lower bound of the random number returned.

   maxValue: The exclusive upper bound of the random number returned. maxValue must be greater than or equal 

    to minValue.

  

   Returns: A 32-bit signed integer greater than or equal to minValue and less than maxValue; that is,the 

    range of return values includes minValue but not maxValue. If minValue equals maxValue,minValue 

    is returned.

  

  Next(self: Random) -> int

  

   Returns a nonnegative random number.

   Returns: A 32-bit signed integer greater than or equal to zero and less than System.Int32.MaxValue.
  """
  pass
 def NextBytes(self,buffer):
  """
  NextBytes(self: Random,buffer: Array[Byte])

   Fills the elements of a specified array of bytes with random numbers.

  

   buffer: An array of bytes to contain random numbers.
  """
  pass
 def NextDouble(self):
  """
  NextDouble(self: Random) -> float

  

   Returns a random number between 0.0 and 1.0.

   Returns: A double-precision floating point number greater than or equal to 0.0,and less than 1.0.
  """
  pass
 def Sample(self,*args):
  """
  Sample(self: Random) -> float

  

   Returns a random number between 0.0 and 1.0.

   Returns: A double-precision floating point number greater than or equal to 0.0,and less than 1.0.
  """
  pass
 @staticmethod
 def __new__(self,Seed=None):
  """
  __new__(cls: type)

  __new__(cls: type,Seed: int)
  """
  pass



class DispIdAttribute(Attribute,_Attribute):
 """
 Specifies the COM dispatch identifier (DISPID) of a method,field,or property.

 

 DispIdAttribute(dispId: int)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,dispId):
  """ __new__(cls: type,dispId: int) """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the DISPID for the member.



Get: Value(self: DispIdAttribute) -> int



"""





class DataGridViewCellMouseEventArgs(MouseEventArgs):
 """
 Provides data for mouse events raised by a System.Windows.Forms.DataGridView whenever the mouse is moved within a System.Windows.Forms.DataGridViewCell.

 

 DataGridViewCellMouseEventArgs(columnIndex: int,rowIndex: int,localX: int,localY: int,e: MouseEventArgs)
 """
 @staticmethod
 def __new__(self,columnIndex,rowIndex,localX,localY,e):
  """ __new__(cls: type,columnIndex: int,rowIndex: int,localX: int,localY: int,e: MouseEventArgs) """
  pass
 ColumnIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the zero-based column index of the cell.



Get: ColumnIndex(self: DataGridViewCellMouseEventArgs) -> int



"""

 RowIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the zero-based row index of the cell.



Get: RowIndex(self: DataGridViewCellMouseEventArgs) -> int



"""





class ConsoleKeyInfo(object):
 """
 Describes the console key that was pressed,including the character represented by the console key and the state of the SHIFT,ALT,and CTRL modifier keys.

 

 ConsoleKeyInfo(keyChar: Char,key: ConsoleKey,shift: bool,alt: bool,control: bool)
 """
 def Equals(self,*__args):
  """
  Equals(self: ConsoleKeyInfo,obj: ConsoleKeyInfo) -> bool

  

   Gets a value indicating whether the specified System.ConsoleKeyInfo object is equal to the 

    current System.ConsoleKeyInfo object.

  

  

   obj: An object to compare to the current System.ConsoleKeyInfo object.

   Returns: true if obj is equal to the current System.ConsoleKeyInfo object; otherwise,false.

  Equals(self: ConsoleKeyInfo,value: object) -> bool

  

   Gets a value indicating whether the specified object is equal to the current 

    System.ConsoleKeyInfo object.

  

  

   value: An object to compare to the current System.ConsoleKeyInfo object.

   Returns: true if value is a System.ConsoleKeyInfo object and is equal to the current 

    System.ConsoleKeyInfo object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ConsoleKeyInfo) -> int

  

   Returns the hash code for the current System.ConsoleKeyInfo object.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,keyChar,key,shift,alt,control):
  """
  __new__(cls: type,keyChar: Char,key: ConsoleKey,shift: bool,alt: bool,control: bool)

  __new__[ConsoleKeyInfo]() -> ConsoleKeyInfo
  """
  pass
 def __ne__(self,*args):
  pass
 Key=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the console key represented by the current System.ConsoleKeyInfo object.



Get: Key(self: ConsoleKeyInfo) -> ConsoleKey



"""

 KeyChar=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Unicode character represented by the current System.ConsoleKeyInfo object.



Get: KeyChar(self: ConsoleKeyInfo) -> Char



"""

 Modifiers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a bitwise combination of System.ConsoleModifiers values that specifies one or more modifier keys pressed simultaneously with the console key.



Get: Modifiers(self: ConsoleKeyInfo) -> ConsoleModifiers



"""





class HttpStatusCode(Enum,IComparable,IFormattable,IConvertible):
 """
 Contains the values of status codes defined for HTTP.

 

 enum HttpStatusCode,values: Accepted (202),Ambiguous (300),BadGateway (502),BadRequest (400),Conflict (409),Continue (100),Created (201),ExpectationFailed (417),Forbidden (403),Found (302),GatewayTimeout (504),Gone (410),HttpVersionNotSupported (505),InternalServerError (500),LengthRequired (411),MethodNotAllowed (405),Moved (301),MovedPermanently (301),MultipleChoices (300),NoContent (204),NonAuthoritativeInformation (203),NotAcceptable (406),NotFound (404),NotImplemented (501),NotModified (304),OK (200),PartialContent (206),PaymentRequired (402),PreconditionFailed (412),ProxyAuthenticationRequired (407),Redirect (302),RedirectKeepVerb (307),RedirectMethod (303),RequestedRangeNotSatisfiable (416),RequestEntityTooLarge (413),RequestTimeout (408),RequestUriTooLong (414),ResetContent (205),SeeOther (303),ServiceUnavailable (503),SwitchingProtocols (101),TemporaryRedirect (307),Unauthorized (401),UnsupportedMediaType (415),Unused (306),UpgradeRequired (426),UseProxy (305)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Accepted=None
 Ambiguous=None
 BadGateway=None
 BadRequest=None
 Conflict=None
 Continue=None
 Created=None
 ExpectationFailed=None
 Forbidden=None
 Found=None
 GatewayTimeout=None
 Gone=None
 HttpVersionNotSupported=None
 InternalServerError=None
 LengthRequired=None
 MethodNotAllowed=None
 Moved=None
 MovedPermanently=None
 MultipleChoices=None
 NoContent=None
 NonAuthoritativeInformation=None
 NotAcceptable=None
 NotFound=None
 NotImplemented=None
 NotModified=None
 OK=None
 PartialContent=None
 PaymentRequired=None
 PreconditionFailed=None
 ProxyAuthenticationRequired=None
 Redirect=None
 RedirectKeepVerb=None
 RedirectMethod=None
 RequestedRangeNotSatisfiable=None
 RequestEntityTooLarge=None
 RequestTimeout=None
 RequestUriTooLong=None
 ResetContent=None
 SeeOther=None
 ServiceUnavailable=None
 SwitchingProtocols=None
 TemporaryRedirect=None
 Unauthorized=None
 UnsupportedMediaType=None
 Unused=None
 UpgradeRequired=None
 UseProxy=None
 value__=None




class SerializableAttribute(Attribute,_Attribute):
 """
 Indicates that a class can be serialized. This class cannot be inherited.

 

 SerializableAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



"""Provide access to Revit Journal Files."""
import re
import os.path as op

from pyrevit import HOST_APP


__all__ = ('get_journals_folder', 'get_current_journal_file',
           'get_current_session_id')


def get_journals_folder():
    return op.dirname(HOST_APP.app.RecordingJournalFilename)


def get_current_journal_file():
    return HOST_APP.app.RecordingJournalFilename


def get_current_session_id():
    re_finder = re.compile(r'.*>Session\s+(\$.{8}).*')
    journal_file = get_current_journal_file()
    with open(journal_file, "r") as jfile:
        for jline in reversed(jfile.readlines()):
            match = re_finder.match(jline)
            if match:
                return match.groups()[0]



"""Base module to handle extension binary caching."""
import pickle

from pyrevit import PyRevitException
from pyrevit.coreutils import appdata
from pyrevit.coreutils.logger import get_logger

#pylint: disable=W0703,C0302,C0103
mlogger = get_logger(__name__)


loaded_extensions = []


def _get_cache_file(cached_ext):
    return appdata.get_data_file(file_id='cache_{}'.format(cached_ext.name),
                                 file_ext='pickle')


def update_cache(parsed_ext):
    try:
        mlogger.debug('Writing cache for: %s', parsed_ext)
        cache_file = _get_cache_file(parsed_ext)
        mlogger.debug('Cache file is: %s', cache_file)
        with open(cache_file, 'wb') as bin_cache_file:
            pickle.dump(parsed_ext, bin_cache_file, pickle.HIGHEST_PROTOCOL)
    except Exception as err:
        raise PyRevitException('Error writing cache for: {} | {}'
                               .format(parsed_ext, err))


def get_cached_extension(installed_ext):
    for loaded_ext in loaded_extensions:
        if loaded_ext.name == installed_ext.name:
            return loaded_ext

    try:
        mlogger.debug('Reading cache for: %s', installed_ext)
        cache_file = _get_cache_file(installed_ext)
        mlogger.debug('Cache file is: %s', cache_file)
        with open(cache_file, 'rb') as bin_cache_file:
            unpickled_pkg = pickle.load(bin_cache_file)
    except Exception as err:
        raise PyRevitException('Error reading cache for: {} | {}'
                               .format(installed_ext, err))

    return unpickled_pkg


def is_cache_valid(extension):
    try:
        cached_ext = get_cached_extension(extension)
        mlogger.debug('Extension cache directory is: %s for: %s',
                      extension.directory, extension)
        cache_dir_valid = \
            cached_ext.directory == extension.directory

        mlogger.debug('Extension cache version is: %s for: %s',
                      extension.pyrvt_version, extension)
        cache_version_valid = \
            cached_ext.pyrvt_version == extension.pyrvt_version

        mlogger.debug('Extension hash value is: %s for: %s',
                      extension.dir_hash_value, extension)
        cache_hash_valid = \
            cached_ext.dir_hash_value == extension.dir_hash_value

        cache_valid = \
            cache_dir_valid and cache_version_valid and cache_hash_valid

        # add loaded package to list so it can be recovered later
        if cache_valid:
            loaded_extensions.append(cached_ext)

        # cache is valid if both version and hash value match
        return cache_valid

    except PyRevitException as err:
        mlogger.debug('Error reading cache file or file is not available: %s',
                      err)
        return False

    except Exception as err:
        mlogger.debug('Error determining cache validity: %s | %s',
                      extension, err)
        return False



class KeySpline(Freezable,ISealable,IFormattable):
 """
 This class is used by a spline key frame to define animation progress.

 

 KeySpline(controlPoint1: Point,controlPoint2: Point)

 KeySpline()

 KeySpline(x1: float,y1: float,x2: float,y2: float)
 """
 def CloneCore(self,*args):
  """
  CloneCore(self: KeySpline,sourceFreezable: Freezable)

   Makes this instance a deep copy of the specified System.Windows.Media.Animation.KeySpline. When 

    copying dependency properties,this method copies resource references and data bindings (but 

    they might no longer resolve) but not animations or their current values.

  

  

   sourceFreezable: The System.Windows.Media.Animation.KeySpline to clone.
  """
  pass
 def CloneCurrentValueCore(self,*args):
  """
  CloneCurrentValueCore(self: KeySpline,sourceFreezable: Freezable)

   Makes this instance a modifiable deep copy of the specified 

    System.Windows.Media.Animation.KeySpline using current property values. Resource references,

    data bindings,and animations are not copied,but their current values are.

  

  

   sourceFreezable: The System.Windows.Media.Animation.KeySpline to clone.
  """
  pass
 def CreateInstance(self,*args):
  """
  CreateInstance(self: Freezable) -> Freezable

  

   Initializes a new instance of the System.Windows.Freezable class.

   Returns: The new instance.
  """
  pass
 def CreateInstanceCore(self,*args):
  """
  CreateInstanceCore(self: KeySpline) -> Freezable

  

   Creates a new instance of System.Windows.Media.Animation.KeySpline.

   Returns: A new instance of System.Windows.Media.Animation.KeySpline.
  """
  pass
 def FreezeCore(self,*args):
  """
  FreezeCore(self: Freezable,isChecking: bool) -> bool

  

   Makes the System.Windows.Freezable object unmodifiable or tests whether it can be made 

    unmodifiable.

  

  

   isChecking: true to return an indication of whether the object can be frozen (without actually freezing it); 

    false to actually freeze the object.

  

   Returns: If isChecking is true,this method returns true if the System.Windows.Freezable can be made 

    unmodifiable,or false if it cannot be made unmodifiable. If isChecking is false,this method 

    returns true if the if the specified System.Windows.Freezable is now unmodifiable,or false if 

    it cannot be made unmodifiable.
  """
  pass
 def GetAsFrozenCore(self,*args):
  """
  GetAsFrozenCore(self: KeySpline,sourceFreezable: Freezable)

   Makes this instance a clone of the specified System.Windows.Media.Animation.KeySpline object.

  

   sourceFreezable: The System.Windows.Media.Animation.KeySpline object to clone.
  """
  pass
 def GetCurrentValueAsFrozenCore(self,*args):
  """
  GetCurrentValueAsFrozenCore(self: KeySpline,sourceFreezable: Freezable)

   Makes this instance a frozen clone of the specified System.Windows.Media.Animation.KeySpline. 

    Resource references,data bindings,and animations are not copied,but their current values are.

  

  

   sourceFreezable: The System.Windows.Media.Animation.KeySpline to copy and freeze.
  """
  pass
 def GetSplineProgress(self,linearProgress):
  """
  GetSplineProgress(self: KeySpline,linearProgress: float) -> float

  

   Calculates spline progress from a supplied linear progress.

  

   linearProgress: The linear progress to evaluate.

   Returns: The calculated spline progress.
  """
  pass
 def OnChanged(self,*args):
  """
  OnChanged(self: KeySpline)

   Called when the current System.Windows.Media.Animation.KeySpline object is modified.
  """
  pass
 def OnFreezablePropertyChanged(self,*args):
  """
  OnFreezablePropertyChanged(self: Freezable,oldValue: DependencyObject,newValue: DependencyObject,property: DependencyProperty)

   This member supports the Windows Presentation Foundation (WPF) infrastructure and is not 

    intended to be used directly from your code.

  

  

   oldValue: The previous value of the data member.

   newValue: The current value of the data member.

   property: The property that changed.

  OnFreezablePropertyChanged(self: Freezable,oldValue: DependencyObject,newValue: DependencyObject)

   Ensures that appropriate context pointers are established for a 

    System.Windows.DependencyObjectType data member that has just been set.

  

  

   oldValue: The previous value of the data member.

   newValue: The current value of the data member.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: Freezable,e: DependencyPropertyChangedEventArgs)

   Overrides the System.Windows.DependencyObject implementation of 

    System.Windows.DependencyObject.OnPropertyChanged(System.Windows.DependencyPropertyChangedEventAr

    gs) to also invoke any System.Windows.Freezable.Changed handlers in response to a changing 

    dependency property of type System.Windows.Freezable.

  

  

   e: Event data that contains information about which property changed,and its old and new values.
  """
  pass
 def ReadPreamble(self,*args):
  """
  ReadPreamble(self: Freezable)

   Ensures that the System.Windows.Freezable is being accessed from a valid thread. Inheritors of 

    System.Windows.Freezable must call this method at the beginning of any API that reads data 

    members that are not dependency properties.
  """
  pass
 def ShouldSerializeProperty(self,*args):
  """
  ShouldSerializeProperty(self: DependencyObject,dp: DependencyProperty) -> bool

  

   Returns a value that indicates whether serialization processes should serialize the value for 

    the provided dependency property.

  

  

   dp: The identifier for the dependency property that should be serialized.

   Returns: true if the dependency property that is supplied should be value-serialized; otherwise,false.
  """
  pass
 def ToString(self,formatProvider=None):
  """
  ToString(self: KeySpline,formatProvider: IFormatProvider) -> str

  

   Creates a string representation of this System.Windows.Media.Animation.KeySpline based on the 

    supplied System.IFormatProvider.

  

  

   formatProvider: The format provider to use. If provider is null,the current culture is used.

   Returns: A string representation of this instance of System.Windows.Media.Animation.KeySpline.

  ToString(self: KeySpline) -> str

  

   Creates a string representation of this instance of System.Windows.Media.Animation.KeySpline 

    based on the current culture.

  

   Returns: A string representation of this System.Windows.Media.Animation.KeySpline.
  """
  pass
 def WritePostscript(self,*args):
  """
  WritePostscript(self: Freezable)

   Raises the System.Windows.Freezable.Changed event for the System.Windows.Freezable and invokes 

    its System.Windows.Freezable.OnChanged method. Classes that derive from System.Windows.Freezable 

    should call this method at the end of any API that modifies class members that are not stored as 

    dependency properties.
  """
  pass
 def WritePreamble(self,*args):
  """
  WritePreamble(self: Freezable)

   Verifies that the System.Windows.Freezable is not frozen and that it is being accessed from a 

    valid threading context. System.Windows.Freezable inheritors should call this method at the 

    beginning of any API that writes to data members that are not dependency properties.
  """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,x1: float,y1: float,x2: float,y2: float)

  __new__(cls: type,controlPoint1: Point,controlPoint2: Point)
  """
  pass
 def __str__(self,*args):
  pass
 ControlPoint1=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The first control point used to define a Bezier curve that describes a System.Windows.Media.Animation.KeySpline.



Get: ControlPoint1(self: KeySpline) -> Point



Set: ControlPoint1(self: KeySpline)=value

"""

 ControlPoint2=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The second control point used to define a Bezier curve that describes a System.Windows.Media.Animation.KeySpline.



Get: ControlPoint2(self: KeySpline) -> Point



Set: ControlPoint2(self: KeySpline)=value

"""


